@@ -1,21 +1,17 @@
-import sys
 from pathlib import Path
 
-from antareslauncher.main import run_with, MainParameters
-from antareslauncher.main_option_parser import (
-    MainOptionParser,
-    ParserParameters,
-)
+from antareslauncher.config import Config, get_config_path
+from antareslauncher.main import MainParameters, run_with
+from antareslauncher.main_option_parser import MainOptionParser, ParserParameters
 from antareslauncher.parameters_reader import ParametersReader
 
-DATA_DIR = Path(__file__).parent.resolve() / "data"
-SSH_JSON_FILE = DATA_DIR / "sshconfig.json"
-YAML_CONF_FILE = DATA_DIR / "configuration.yaml"
-
 
 def main():
+    config_path: Path = get_config_path()
+    config = Config.load_config(config_path)
     param_reader = ParametersReader(
-        json_ssh_conf=SSH_JSON_FILE, yaml_filepath=YAML_CONF_FILE
+        json_ssh_conf=config.ssh_config.config_path,
+        yaml_filepath=config.config_path,
     )
     parser_parameters: ParserParameters = param_reader.get_parser_parameters()
     parser: MainOptionParser = MainOptionParser(parser_parameters)
@@ -23,8 +19,6 @@ def main():
     arguments = parser.parse_args()
     main_parameters: MainParameters = param_reader.get_main_parameters()
     run_with(arguments=arguments, parameters=main_parameters, show_banner=True)
-    if not len(sys.argv) > 1:
-        input("Press ENTER to exit.")
 
 
 if __name__ == "__main__":
