@@ -3,6 +3,7 @@ import fnmatch
 import logging
 import socket
 import stat
+import textwrap
 import time
 from pathlib import Path, PurePosixPath
 from typing import List, Tuple
@@ -288,21 +289,26 @@ class SshConnection:
             error: The standard error of the command
         """
         output = None
-        self.logger.info(f"Executing command on remote server: {command}")
         try:
             with self.ssh_client() as client:
+                # fmt: off
                 self.logger.info(f"Running SSH command [{command}]...")
                 stdin, stdout, stderr = client.exec_command(command, timeout=30)
-                output = stdout.read().decode("utf-8")
-                error = stderr.read().decode("utf-8")
+                output = stdout.read().decode("utf-8").strip()
+                error = stderr.read().decode("utf-8").strip()
+                self.logger.info(f"SSH command stdout:\n{textwrap.indent(output, 'SSH OUTPUT> ')}")
+                self.logger.info(f"SSH command stderr:\n{textwrap.indent(error, 'SSH ERROR> ')}")
+                # fmt: on
         except socket.timeout:
-            error = f"Command timed out: {command}"
-        except paramiko.SSHException:
-            error = f"Failed to execute {command}"
-        except ConnectionFailedException:
-            error = f"Failed to connect to remote host and execute {command}"
+            error = f"SSH command timed out: [{command}]"
+            self.logger.error(error)
+        except paramiko.SSHException as e:
+            error = f"SSH command failed to execute [{command}]: {e}"
+            self.logger.error(error)
+        except ConnectionFailedException as e:
+            error = f"SSH connection failed: {e}"
+            self.logger.error(error)
 
-        self.logger.info(f"Command output:\nOutput: {output}\nError: {error}")
         return output, error
 
     def upload_file(self, src: str, dst: str):
