@@ -37,7 +37,7 @@ class StudyDTO:
     xpansion_mode: Optional[str] = None
     run_mode: Modes = Modes.antares
     post_processing: bool = False
-    other_options: Optional[str] = None
+    other_options: str = ""
 
     def __post_init__(self):
         self.name = Path(self.path).name
