@@ -16,7 +16,8 @@ from antareslauncher.use_cases.kill_job.job_kill_controller import (
 class TestIntegrationJobKilController:
     def setup_method(self):
         slurm_script_features = SlurmScriptFeatures("slurm_script_path")
-        env = RemoteEnvironmentWithSlurm(mock.Mock(), slurm_script_features)
+        connection = mock.Mock(home_dir="path/to/home")
+        env = RemoteEnvironmentWithSlurm(connection, slurm_script_features)
         self.job_kill_controller = JobKillController(env, mock.Mock(), repo=mock.Mock())
 
     @pytest.mark.integration_test
